# Ansible Role: `solr`

[![CI](https://github.com/shaneholloman/ansible-role-solr/actions/workflows/ci.yml/badge.svg)](https://github.com/shaneholloman/ansible-role-solr/actions/workflows/ci.yml)

Installs [Apache Solr](http://lucene.apache.org/solr/) on Linux servers.

## Requirements

Java must be available on the server. You can easily install Java using the `shaneholloman.java` role. Make sure the Java version installed meets the minimum requirements of Solr (e.g. Java 8 for Solr 6+).

This role is currently tested and working with Solr 3.x, 4.x, 5.x, 6.x, 7.x, and 8.x.

## Role Variables

Available variables are listed below, along with default values (see `defaults/main.yml`):

```yml
solr_workspace: /root
```

Files will be downloaded to this path on the remote server before being moved into place.

```yml
solr_create_user: true
solr_user: solr
solr_group: "{{ solr_user }}"
```

Solr will be run under the `solr_user`. Set `solr_create_user` to `false` if `solr_user` is created before this role runs, or if you're using Solr 5+ and want Solr's own installation script to set up the user. By default, `solr_group` equals `solr_user`, but it can be overwritten to fit your own configuration.

```yml
solr_version: "9.4.0"
```

The Apache Solr version to install. For a full list, see [available Apache Solr versions](http://archive.apache.org/dist/lucene/solr/).

```yml
solr_mirror: "https://archive.apache.org/dist"
```

The Apache Project mirror from which the Solr tarball will be downloaded. In case of slow download speed or timeouts it is useful to set the mirror to the one suggested by Apache's [mirror download site](https://www.apache.org/dyn/closer.cgi/lucene/solr/).

```yml
solr_remove_cruft: false
```

Whether to remove unnecessary documentation and examples from the solr directory.

```yml
solr_service_manage: true
solr_service_name: solr
solr_service_state: started
```

By default, this role will manage the `solr` service, ensuring it is enabled at system boot and is running. You can ensure Solr is stopped by setting `solr_service_state: stopped`, or you can disable this role's management of the `solr` service entirely by setting `solr_service_manage: false`. You may also want to set `solr_restart_handler_enabled: false` (documented later) in this case.

```yml
solr_install_dir: /opt
solr_install_path: /opt/solr
```

The path where Apache Solr will be installed. For Solr 5+, the `solr_install_dir` will be used by Solr's installation script. For Solr < 5, the Solr installation files will be copied in place in the `solr_install_path`.

```yml
solr_home: /var/solr
```

The path where local Solr data (search collections and configuration) will be stored. Should typically be outside of the `solr_path`, to make Solr upgrades easier.

```yml
solr_port: "8983"
```

The port on which Solr will run.

```yml
solr_xms: "256M"
solr_xmx: "512M"
```

Memory settings for the JVM. These should be set as high as you can allow for best performance and to reduce the chance of Solr restarting itself due to OOM situations.

```yml
solr_timezone: "UTC"
```

Default timezone of JVM running solr. You can override this if needed when using dataimport and delta imports (ex: comparing against a MySQL external data source). Read through Apache Solr's [Working with Dates](https://cwiki.apache.org/confluence/display/solr/Working+with+Dates) documentation for more background.

```yml
solr_opts: "$SOLR_OPTS -Dlog4j2.formatMsgNoLookups=true"
```

Solr options. This option was added to the role in part to mitigate [CVE-2021-44228](https://solr.apache.org/security.html#apache-solr-affected-by-apache-log4j-cve-2021-44228).

```yml
solr_cores:
    - collection1
```

A list of cores / collections which should exist on the server. Each one will be created (if it doesn't exist already) using the default example configuration that ships with Solr. Note that this variable only applies when using Solr 5+.

```yml
solr_connect_host: localhost
```

The hostname or IP address on which Solr will be reachable. `localhost` should work in most circumstances, but there are special cases where you may only be able to access the local Solr instance via another IP or hostname.

```yml
solr_restart_handler_enabled: true
```

Whether the `Restart solr` handler should be used or not. If you're building containers or AMIs, you might need to disable the restart handler for a provisioning run.

### Variables used only for Solr < 5

The following variables are currently only applied to installations of Solr 4 and below:

```sh
solr_log_file_path: /var/log/solr.log
```

Path where Solr log file will be created.

```yml
solr_host: "0.0.0.0"
```

The hostname or IP address to which Solr will bind. Defaults to `0.0.0.0` which allows Solr to listen on all interfaces.

## Dependencies

None.

## Example Playbook

```yml
- hosts: solr-servers
    roles:
    - shaneholloman.java
    - shaneholloman.solr
```

## License

Unlicense

## Author Information

This role was created in 2023
